==> jaxx-runtime-2.0-sources.jar: jaxx/runtime/swing/navigation/NavigationMultiContentUI.java <==
/*
 * *##%
 * JAXX Runtime
 * Copyright (C) 2008 - 2009 CodeLutin
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * ##%*
 */

package jaxx.runtime.swing.navigation;

import java.awt.Component;
import java.util.List;

/**
 * Contract on a content UI with list of beans.
 *
 * @author sletellier
 * @since 2.0.1
 */
public interface NavigationMultiContentUI extends NavigationContentUI{

    /**
     * Init the ui just before been opened by the method
     * {@link NavigationMultiTreeHandler#openUI(Component, List)}.
     *
     * @param nodes the selected node associated to the ui
     * @throws Exception if any pb while opening the content's ui
     */
    void openUI(List<NavigationTreeNode> nodes) throws Exception;

    /**
     * Clean the ui after been closed by the method
     * {@link NavigationTreeHandler#closeUI(Component)}.
     *
     * @param nodes the selected node associated to the ui
     * @throws Exception if any pb when closing the content'sui
     * @see NavigationTreeHandler#closeUI(Component)
     */
    void closeUI(List<NavigationTreeNode> nodes) throws Exception;
}

==> jaxx-runtime-2.0.1-sources.jar: jaxx/runtime/swing/navigation/NavigationMultiContentUI.java <==
/*
 * *##%
 * JAXX Runtime
 * Copyright (C) 2008 - 2009 CodeLutin
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * ##%*
 */

package jaxx.runtime.swing.navigation;

import jaxx.runtime.swing.navigation.handler.NavigationMultiTreeHandler;

import java.awt.*;
import java.util.List;

/**
 * Contract on a content UI with list of beans.
 *
 * @author sletellier
 * @since 2.0.1
 */
public interface NavigationMultiContentUI<E extends NavigationNode<E>> extends NavigationContentUI<E> {

    /**
     * Init the ui just before been opened by the method {@link
     * NavigationMultiTreeHandler#openUI(Component, List)}.
     *
     * @param nodes the selected node associated to the ui
     * @throws Exception if any pb while opening the content's ui
     * @see NavigationMultiTreeHandler#openUI(Component, List)
     */
    void openUI(List<E> nodes) throws Exception;

    /**
     * Clean the ui after been closed by the method {@link
     * NavigationMultiTreeHandler#closeUI(Component)}.
     *
     * @param nodes the selected node associated to the ui
     * @throws Exception if any pb when closing the content'sui
     * @see NavigationMultiTreeHandler#closeUI(Component)
     */
    void closeUI(List<E> nodes) throws Exception;
}
